@@ -26,7 +26,7 @@
      ## check proper design of the model frame
     l1 <- sapply(rhs, function(z) length(unique(z)))
     if (!any(sapply(2:nlevs, function(z) l1[z] <= l1[z-1])))
-        stop("number of levels are inapropriate, check sequence")
+        stop("number of levels are inappropriate, check sequence")
     rval <- list()
     rval[[1]] <- rhs[,nlevs]
     nCol <- nlevs - 1
@@ -128,7 +128,7 @@
     attr(sim, "call") <- call
     attr(sim$oecosimu$simulated, "index") <- index
     attr(sim$oecosimu$simulated, "scales") <- scales
-    attr(sim$oecosimu$simulated, "global") <- TRUE
+    attr(sim$oecosimu$simulated, "global") <- global
     attr(sim, "n.levels") <- nlevs
     attr(sim, "terms") <- tlab
     attr(sim, "model") <- rhs
