@@ -1,8 +1,9 @@
-"print.vectorfit" <-
+`print.vectorfit` <-
     function (x, ...) 
 {
     out <- cbind(x$arrows, r2 = x$r, "Pr(>r)" = x$pvals)
-    printCoefmat(out, na.print = "", ...)
+    printCoefmat(out, na.print = "",
+                 zap.ind = seq_len(ncol(out)-2), ...)
     if (x$permutations) {
         cat("P values based on", x$permutations, "permutations")
         if (!is.null(x$strata)) 
